@@ -1,12 +1,18 @@
 from openaleph_search.index.util import unpack_result
 from openaleph_search.parse.parser import QueryParser, SearchQueryParser
 from openaleph_search.query.base import Query
-from openaleph_search.query.queries import EntitiesQuery, GeoDistanceQuery, MatchQuery
+from openaleph_search.query.queries import (
+    EntitiesQuery,
+    GeoDistanceQuery,
+    MatchQuery,
+    MoreLikeThisQuery,
+)
 
 __all__ = [
     "EntitiesQuery",
     "GeoDistanceQuery",
     "MatchQuery",
+    "MoreLikeThisQuery",
     "Query",
     "QueryParser",
     "SearchQueryParser",
@@ -14,4 +20,4 @@ __all__ = [
 ]
 
 
-__version__ = "0.0.5"
+__version__ = "5.0.1"
