@@ -2,7 +2,7 @@ from anystore.settings import BaseSettings
 from pydantic import AliasChoices, Field, HttpUrl
 from pydantic_settings import SettingsConfigDict
 
-__version__ = "0.0.0"
+__version__ = "5.0.1"
 
 MAX_PAGE = 9999
 BULK_PAGE = 1000
@@ -23,7 +23,10 @@ class Settings(BaseSettings):
     auth_field: str = "dataset"
     """Default field to filter/apply auth on"""
 
-    uri: HttpUrl | list[HttpUrl] = HttpUrl("http://localhost:9200")
+    uri: HttpUrl | list[HttpUrl] = Field(
+        default=HttpUrl("http://localhost:9200"), alias="openaleph_elasticsearch_uri"
+    )
+
     timeout: int = 60
     max_retries: int = 3
     retry_on_timeout: bool = True
